emit_array

Function emit_array 

pub fn emit_array(words: &[String]) -> String
One bash array literal: ["a", "b c"]('a' 'b c'). The shape a message, an answer and every captured column travel as, and the inverse of parse_array.